@@ -10,9 +10,9 @@ use Carp qw(confess);
 use Catalyst::Model::REST::Serializer;
 use Catalyst::Model::REST::Response;
 use LWP::UserAgent;
-use HTTP::Request::Common;
+use HTTP::Request::Common qw/POST GET PUT DELETE/;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 has 'server' => (
     isa => 'Str',
@@ -54,10 +54,10 @@ sub _ua {
 sub post {
 	my ($self, $endpoint, $data) = @_;
 	my $uri = $self->server.$endpoint;
-	my $res = $self->_ua->request(POST($uri,
+	my $res = defined $data ? $self->_ua->request(POST($uri,
 		Content_Type => $self->_serializer->content_type,
 		Content => $self->_serializer->serialize($data)
-	));
+	)) : $self->_ua->request(POST($uri));
 	# Try to find a serializer for the result content
 	my $content_type = $res->content_type;
 	my $deserializer = $self->_serializer($content_type);
@@ -72,10 +72,10 @@ sub post {
 sub get {
 	my ($self, $endpoint, $data) = @_;
 	my $uri = $self->server.$endpoint;
-	my $res = $self->_ua->request(GET($uri,
+	my $res = defined $data ? $self->_ua->request(GET($uri,
 		Content_Type => $self->_serializer->content_type,
 		Content => $self->_serializer->serialize($data)
-	));
+	)) : $self->_ua->request(GET($uri));
 	# Try to find a serializer for the result content
 	my $content_type = $res->content_type;
 	my $deserializer = $self->_serializer($content_type);
@@ -90,10 +90,10 @@ sub get {
 sub put {
 	my ($self, $endpoint, $data) = @_;
 	my $uri = $self->server.$endpoint;
-	my $res = $self->_ua->request(PUT($uri,
+	my $res = defined $data ? $self->_ua->request(PUT($uri,
 		Content_Type => $self->_serializer->content_type,
 		Content => $self->_serializer->serialize($data)
-	));
+	)) : $self->_ua->request(PUT($uri));
 	# Try to find a serializer for the result content
 	my $content_type = $res->content_type;
 	my $deserializer = $self->_serializer($content_type);
@@ -108,10 +108,10 @@ sub put {
 sub delete {
 	my ($self, $endpoint, $data) = @_;
 	my $uri = $self->server.$endpoint;
-	my $res = $self->_ua->request(DELETE($uri,
+	my $res = defined $data ? $self->_ua->request(DELETE($uri,
 		Content_Type => $self->_serializer->content_type,
 		Content => $self->_serializer->serialize($data)
-	));
+	)) : $self->_ua->request(DELETE($uri));
 	# Try to find a serializer for the result content
 	my $content_type = $res->content_type;
 	my $deserializer = $self->_serializer($content_type);
